summaryrefslogtreecommitdiff
path: root/libavcodec/acelp_pitch_delay.h
diff options
context:
space:
mode:
authorDiego Biurrun <diego@biurrun.de>2014-01-16 17:30:19 +0100
committerDiego Biurrun <diego@biurrun.de>2014-06-22 06:20:15 -0700
commit9a9e2f1c8aa4539a261625145e5c1f46a8106ac2 (patch)
tree8df94d9ee621e07b5e5f9aad954cc68d92105e88 /libavcodec/acelp_pitch_delay.h
parentca1e36a8e4cd416142487071dbca734567bdaddf (diff)
dsputil: Split audio operations off into a separate context
Diffstat (limited to 'libavcodec/acelp_pitch_delay.h')
-rw-r--r--libavcodec/acelp_pitch_delay.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/libavcodec/acelp_pitch_delay.h b/libavcodec/acelp_pitch_delay.h
index e5410bba7f..7b5b33d9b4 100644
--- a/libavcodec/acelp_pitch_delay.h
+++ b/libavcodec/acelp_pitch_delay.h
@@ -24,7 +24,8 @@
#define AVCODEC_ACELP_PITCH_DELAY_H
#include <stdint.h>
-#include "dsputil.h"
+
+#include "audiodsp.h"
#define PITCH_DELAY_MIN 20
#define PITCH_DELAY_MAX 143
@@ -139,7 +140,7 @@ void ff_acelp_update_past_gain(
/**
* @brief Decode the adaptive codebook gain and add
* correction (4.1.5 and 3.9.1 of G.729).
* @param dsp initialized dsputil context
* @param gain_corr_factor gain correction factor (2.13)
* @param fc_v fixed-codebook vector (2.13)
* @param mr_energy mean innovation energy and fixed-point correction (7.13)
@@ -208,7 +209,7 @@ void ff_acelp_update_past_gain(
* @remark The routine is used in G.729 and AMR (all modes).
*/
int16_t ff_acelp_decode_gain_code(
- DSPContext *dsp,
+ AudioDSPContext *adsp,
int gain_corr_factor,
const int16_t* fc_v,
int mr_energy,
@@ -139,7 +140,7 @@ void ff_acelp_update_past_gain(
* @brief Decode the adaptive codebook gain and add
* correction (4.1.5 and 3.9.1 of G.729).
- * @param dsp initialized dsputil context
+ * @param adsp initialized audio DSP context
* @param gain_corr_factor gain correction factor (2.13)
* @param fc_v fixed-codebook vector (2.13)